pub struct McpServer { /* private fields */ }Expand description
MCP Server for Myko stdio transport.
Automatically exposes all registered queries, reports, and commands through the MCP protocol.
Implementations
Sourceimpl McpServer
impl McpServer
Sourcepub fn with_info(name: impl Into<String>, version: impl Into<String>) -> Self
pub fn with_info(name: impl Into<String>, version: impl Into<String>) -> Self
Create a new MCP server with custom name and version.
Sourcepub fn with_instructions(self, instructions: impl Into<String>) -> Self
pub fn with_instructions(self, instructions: impl Into<String>) -> Self
Set the optional instructions text returned in the MCP initialize
response. Surfaced to the model by the connecting client on connect.