ClientSession

Struct ClientSession 

pub struct ClientSession<W>
where W: WsWriter,
{ pub client_id: Arc<str>, /* private fields */ }
A WebSocket client session that manages subscriptions.

When dropped, all subscription guards are dropped, automatically cleaning up all reactive subscriptions.

Fields

client_id: Arc<str>

Unique client identifier

Implementations

Source

impl<W> ClientSession<W>
where W: WsWriter,

pub fn new(client_id: Arc<str>, writer: W) -> ClientSession<W>

Create a new client session.

pub fn subscribe_query( &mut self, tx: Arc<str>, cell: CellMap<Arc<str>, Arc<dyn AnyItem>, CellImmutable>, window: Option<QueryWindow>, )

Subscribe to a CellMap from a query cell factory.

This is used by WsHandler when the query registration provides a cell factory.

pub fn subscribe_view( &mut self, tx: Arc<str>, cell: CellMap<Arc<str>, Arc<dyn AnyItem>, CellImmutable>, window: Option<QueryWindow>, )

Subscribe to a CellMap from a view cell factory.

pub fn subscribe_view_with_id( &mut self, tx: Arc<str>, view_id: Arc<str>, cell: CellMap<Arc<str>, Arc<dyn AnyItem>, CellImmutable>, window: Option<QueryWindow>, )

Subscribe to a CellMap from a view cell factory with explicit view id for perf logging.

pub fn subscribe_report( &mut self, tx: Arc<str>, report_id: Arc<str>, cell: Cell<Arc<dyn AnyOutput>, CellImmutable>, )

Subscribe to a report cell.

pub fn update_query_window( &mut self, tx: &Arc<str>, window: Option<QueryWindow>, )

Update window for an active query subscription.

pub fn update_view_window(&mut self, tx: &Arc<str>, window: Option<QueryWindow>)

Update window for an active view subscription.

pub fn cancel(&mut self, tx: &Arc<str>)

Cancel a subscription by transaction ID.

pub fn cancel_all(&mut self)

Cancel all subscriptions.

pub fn subscription_count(&self) -> usize

Get the number of active subscriptions.

pub fn has_subscription(&self, tx: &Arc<str>) -> bool

Check if a subscription exists.