pub struct HandlerRegistry { /* private fields */ }Expand description
Registry of all handlers for the cell-based server.
Collects registrations from inventory at construction time and provides O(1) lookup by type/id.
Implementations
Sourceimpl HandlerRegistry
impl HandlerRegistry
Sourcepub fn new() -> HandlerRegistry
pub fn new() -> HandlerRegistry
Create a new handler registry by collecting all registrations from inventory.
Sourcepub fn get_item_parser(
&self,
entity_type: &str,
) -> Option<fn(Value) -> Result<Arc<dyn AnyItem>, Error>>
pub fn get_item_parser( &self, entity_type: &str, ) -> Option<fn(Value) -> Result<Arc<dyn AnyItem>, Error>>
Get an item parse function by entity type name.
Sourcepub fn get_item_buffer_policy(&self, entity_type: &str) -> IngestBufferPolicy
pub fn get_item_buffer_policy(&self, entity_type: &str) -> IngestBufferPolicy
Get the ingest buffering policy for an entity type.
Sourcepub fn get_query(&self, query_id: &str) -> Option<&StoredQueryData>
pub fn get_query(&self, query_id: &str) -> Option<&StoredQueryData>
Get query registration data by query id.
Sourcepub fn get_report(&self, report_id: &str) -> Option<&StoredReportData>
pub fn get_report(&self, report_id: &str) -> Option<&StoredReportData>
Get report registration data by report id.
Sourcepub fn get_view(&self, view_id: &str) -> Option<&StoredViewData>
pub fn get_view(&self, view_id: &str) -> Option<&StoredViewData>
Get view registration data by view id.
Sourcepub fn has_item_parser(&self, entity_type: &str) -> bool
pub fn has_item_parser(&self, entity_type: &str) -> bool
Check if an entity type has a registered parser.
Sourcepub fn entity_types(&self) -> impl Iterator<Item = &Arc<str>>
pub fn entity_types(&self) -> impl Iterator<Item = &Arc<str>>
Get all registered entity type names.
Sourcepub fn report_ids(&self) -> impl Iterator<Item = &Arc<str>>
pub fn report_ids(&self) -> impl Iterator<Item = &Arc<str>>
Get all registered report ids.